/*
 *  dockapp.h
 *
 *  Copyright (C) 2003 Draghicioiu Mihai <misuceldestept@go.ro>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef __DOCKAPP_H__
#define __DOCKAPP_H__

#include <X11/Xlib.h>

extern Display *display;
extern GC       gc;
extern Pixmap   background, backgroundmask, on, off, numbers, buffer;

void make_window();
void process_events();
void update_window();
void free_stuff();

#endif /* __DOCKAPP_H__ */
